#!/bin/bash
# lastact: arturo@2021-10-4
# desc: A propuesta de la CPEPA Ribagorza vamos a modificar el nombre de las cuentas de usuario por temas de igualdad
# - profesor => "docente" (o "profesorado")
# - alumno => "estudiante" (o "alumnado")

TITULO="Igualdad en Cuentas de Usuarios"

# Importamos las funciones básicas de bash definidas en vitalinux:
FICHFUNCS="/usr/bin/vx-funcs-bash"
[ -f "${FICHFUNCS}" ] && . "${FICHFUNCS}"

TEXTO="Debes acceder con permisos de root garantizar la igualdad en las cuentas de usuario ..."
vx-check_user_root "${TEXTO}"

# 1) Preparamos la auditoria del servicio:
LOG="vx-cuentas-usuarios-igualdad.log"
vx-log_xsession -o "${LOG}"

vx-echo_log_titulo1 "SRV-CUENTAS-USUARIOS-IGUALDAD" "${TITULO}"

# 2) Renombramos las cuentas de usuario en caso de ser necesario:
FORCE_IGUALDAD="false"
LISTA_USUARIOS=(
    "profesor:docente:Docente Centro Educativo"
    "alumno:estudiante:Estudiante Centro Educativo"
)

for ELEMENTO in "${LISTA_USUARIOS[@]}"; do
    USU_OLD="${ELEMENTO%%:*}"
    USU_NEW="$(echo "${ELEMENTO}" | cut -d":" -f2)"
    USU_COMMENT="${ELEMENTO##*:}"
    if getent passwd "${USU_OLD}" | grep -q "^${USU_OLD}:"; then
        FORCE_IGUALDAD="true"
        # Obtenemos el HOME del usuario:
        HOMEUSU="$(vx-home-usuario-grafico "${USU_OLD}")"
        # Matamos todo proceso que aún tenga la cuenta de usuario afectada:
        killall -u "${USU_OLD}" &&
            TEXTO="Matamos los procesos de ${USU_OLD} antes de cambiar por ${USU_NEW}" &&
            vx-echo_log_titulo2 "SRV-CUENTAS-USUARIOS-IGUALDAD" "${TEXTO}"
        # Eliminamos para que se regeneren los bookmarks del explorador de archivos:
        FICH_BOOKMARKS="${HOMEUSU/.config/gtk-3.0/bookmarks}"
        [ -f "${FICH_BOOKMARKS}" ] &&
            rm -Rf "${FICH_BOOKMARKS}" &&
            TEXTO="Eliminamos los bookmarks que hubiera para ${USU_OLD}" &&
            vx-echo_log_titulo2 "SRV-CUENTAS-USUARIOS-IGUALDAD" "${TEXTO}"
        # Renombramos la cuenta de usuario para garantizar la igualdad:
        usermod --login "${USU_NEW}" -c "${USU_COMMENT}" --home "/home/${USU_NEW}" -m "${USU_OLD}" &&
            TEXTO="Modificamos el nombre de usuario ${USU_OLD} por ${USU_NEW}" &&
            vx-echo_log_titulo2 "SRV-CUENTAS-USUARIOS-IGUALDAD" "${TEXTO}"
        # Configuramos el inicio de sesión en caso de ser necesario:
        FICH_CONF="/etc/lightdm/lightdm.conf"
        [ -f "${FICH_CONF}" ] &&
            grep -qE "^autologin-user=${USU_OLD}[[:space:]]*$" "${FICH_CONF}" &&
            sed -i "s/^autologin-user=${USU_OLD}/autologin-user=${USU_NEW}/g" "${FICH_CONF}" &&
            TEXTO="Modificamos el inicio de sesión automático de ${USU_OLD} por ${USU_NEW}" &&
            vx-echo_log_titulo2 "SRV-CUENTAS-USUARIOS-IGUALDAD" "${TEXTO}"
        # Renombramos el archivo donde se configuran las cuentas de usuario: idioma, etc.
        DIR="/var/lib/AccountsService/users"
        [ -f "${DIR}/${USU_OLD}" ] &&
            mv "${DIR}/${USU_OLD}" "${DIR}/${USU_NEW}" &&
            TEXTO="Modificamos el AccountsService/Users de ${USU_OLD} por ${USU_NEW}" &&
            vx-echo_log_titulo2 "SRV-CUENTAS-USUARIOS-IGUALDAD" "${TEXTO}"
        # Aditamos lo realizado:
        TEXTO="Se ha terminado de configurar la cuenta de usuario ${USU_OLD} por ${USU_NEW}"
        vx-echo_log_titulo2 "SRV-CUENTAS-USUARIOS-IGUALDAD" "${TEXTO}"
    fi
done

! "${FORCE_IGUALDAD}" &&
    TEXTO="No exiten las cuentas de usuario de alumno y profesor. La igualdad en las cuentas de usuario ya se estableció." &&
    vx-echo_log_titulo2 "SRV-CUENTAS-USUARIOS-IGUALDAD" "${TEXTO}"

# exit 0 # Sin exit para que se puedan ejecutar el resto de scripts
